(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='%s' *)
(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       131,          6]
NotebookDataLength[    171466,       2991]
NotebookOptionsPosition[    167587,       2931]
NotebookOutlinePosition[    168085,       2951]
CellTagsIndexPosition[    168042,       2948]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e841da96-a3b1-47be-bdda-35da93d19369"],

Cell["Chapter 2, Section 2.7, Figure 2.12", "Section",
 CellChangeTimes->{{3.8516824850054398`*^9, 3.8516824897129374`*^9}, {
  3.8521163574828167`*^9, 
  3.85211636131787*^9}},ExpressionUUID->"e0c5f5c8-6081-4d1f-b6a3-\
e70fbf94be83"],

Cell[TextData[{
 "We start by defining a function ",
 StyleBox["r", "Input"],
 " using Eq.(2.20) to give us the radial distance for given values of \
semi-major axis, ",
 StyleBox["a", "Input"],
 ", eccentricity, ",
 StyleBox["e", "Input"],
 ", and true anomaly, ",
 StyleBox["t", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"037fe9f8-0973-4de7-8f87-9d81c9d6a588"],

Cell["r[a_,e_,t_]:=a(1-e^2)/(1+e Cos[t]);", "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"74d5f28f-491d-4df9-9a98-baf58f7ca2bb"],

Cell[TextData[{
 "Use the definition of ",
 StyleBox["r", "Input"],
 " to define a function ",
 StyleBox["ellipse",
  FontWeight->"Bold"],
 " to draw a planar ellipse with semi-major axis ",
 StyleBox["a", "Input"],
 " and eccentricity ",
 StyleBox["e ", "Input"],
 "(see Eq.(2.21))."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.852196917657197*^9, 3.852196933392804*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"15a06966-ec76-434f-8cbd-b97cea0e1abb"],

Cell["\<\
ellipse[a_,e_]:=
ParametricPlot[{r[a,e,t] Cos[t], r[a,e,t] Sin[t]},
               {t,0,2Pi},AspectRatio->Automatic];\
\>", "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"1a2b4798-3239-4416-8e3f-8237e4351cfd"],

Cell[TextData[{
 "Now define two similar functions, ",
 StyleBox["ellipsecom1",
  FontWeight->"Bold"],
 " and ",
 StyleBox["ellipsecom2",
  FontWeight->"Bold"],
 ", to draw ellipses that will be used to draw (i) the path of the centre of \
mass in a frame centred on the central mass, and (i) the path of the central \
mass in a frame centred on the centre of mass.  Note that ",
 StyleBox["ellipsecom1",
  FontWeight->"Bold"],
 " is drawn with a thinner line and that ",
 StyleBox["ellipsecom2",
  FontWeight->"Bold"],
 " is rotated by 180\[Degree] with respect to the original ellipse."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.852196917657197*^9, 3.852196933392804*^9}, {
   3.852196975625827*^9, 3.852197078191415*^9}, {3.8521972131456738`*^9, 
   3.852197291702389*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1bc8946a-0165-4c8f-a798-407bae699c3c"],

Cell["\<\
ellipsecom1[a_,e_]:=
ParametricPlot[{r[a,e,t] Cos[t], r[a,e,t] Sin[t]},
               {t,0,2Pi},PlotStyle->Thickness[0.001],AspectRatio->Automatic];\
\
\>", "Input",
 CellChangeTimes->{{3.8521921094329243`*^9, 3.852192126375309*^9}, {
  3.852192365684702*^9, 3.852192367912116*^9}, {3.852192698029401*^9, 
  3.8521927161974983`*^9}, {3.852192751163292*^9, 3.852192761563353*^9}, {
  3.852192826869783*^9, 3.85219284354883*^9}, {3.852192888280081*^9, 
  3.852192925120772*^9}, {3.852193476869459*^9, 3.852193479482832*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"189049c2-9419-41be-929f-57b64959f251"],

Cell["\<\
ellipsecom2[a_,e_]:=
ParametricPlot[{r[a,e,t+Pi] Cos[t], r[a,e,t+Pi] Sin[t]},
               {t,0,2Pi},AspectRatio->Automatic];\
\>", "Input",
 CellChangeTimes->{{3.8521921094329243`*^9, 3.852192126375309*^9}, {
   3.852192365684702*^9, 3.852192367912116*^9}, {3.852192698029401*^9, 
   3.8521927161974983`*^9}, {3.852192751163292*^9, 3.852192761563353*^9}, {
   3.852192826869783*^9, 3.85219284354883*^9}, {3.852192888280081*^9, 
   3.852192925120772*^9}, {3.852193476869459*^9, 3.852193550126199*^9}, {
   3.852193657954417*^9, 3.852193662093746*^9}, 3.852196345666122*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"78be983d-800c-4e63-a839-32a0d43a5c31"],

Cell[TextData[{
 "Define a function ",
 StyleBox["ksolve", "Input"],
 " to solve Kepler\[CloseCurlyQuote]s Equation to find the eccentric anomaly \
for given values of the mean anomaly ",
 StyleBox["ma", "Input"],
 " and eccentricity ",
 StyleBox["e", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518565908155117`*^9, 3.851856663384062*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"499ef0d3-896f-43ff-ad87-a50c6bd576da"],

Cell["ksolve[ma_,e_]:=FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"e98c7a92-aae2-4838-8992-553373aaa41c"],

Cell[TextData[{
 "Define the function ",
 StyleBox["position",
  FontWeight->"Bold"],
 " to calculate the 2D position vectors of the orbiting mass for given values \
of the mean anomaly ",
 StyleBox["ma", "Input"],
 ", semi-major axis ",
 StyleBox["a", "Input"],
 " and eccentricity ",
 StyleBox["e", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.852116498403043*^9, 
   3.8521165521772747`*^9}, {3.852117652666978*^9, 3.852117655681035*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"038f3591-2174-494e-ae16-414cdb11af73"],

Cell["\<\
position[ma_,a_,e_]:=
Module[
{eca,esq=Sqrt[1-e^2],x,y,r,xd,yd},
eca=ea/.ksolve[ma,e];
ceca=Cos[eca]; seca=Sin[eca];
x=a(ceca-e); y=a*esq*seca;
r=Sqrt[x^2+y^2];
{x,y,r}
]\
\>", "Input",
 CellChangeTimes->{{3.851755150729423*^9, 3.851755153583551*^9}, {
   3.8517552030090723`*^9, 3.851755331050675*^9}, {3.851755386351788*^9, 
   3.851755426371717*^9}, {3.85175553015672*^9, 3.8517556246146727`*^9}, {
   3.851755665965542*^9, 3.8517556784154997`*^9}, {3.851755722935534*^9, 
   3.8517557882609673`*^9}, 3.851755909237783*^9, {3.8517575132539043`*^9, 
   3.8517575290476427`*^9}, {3.851757580153109*^9, 3.8517575886870604`*^9}, {
   3.85211650444783*^9, 3.8521165058873577`*^9}, {3.8521176980564632`*^9, 
   3.852117704176052*^9}, {3.852118416533043*^9, 3.852118417234187*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"6dc29f0b-b5a3-4d3b-abbd-998f5350a3f8"],

Cell["Draw the 2D ellipse.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.8518577960228558`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7c6a061f-df2a-45cd-b45d-24af7e38b1f7"],

Cell["ell=ellipse[1.0,0.5];", "Input",
 CellChangeTimes->{3.812187616753561*^9, 3.85176071108153*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"23829646-9796-4147-80ef-8e664b956745"],

Cell["Define a point for the sun (at the origin) in 2D.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.851857946979704*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"38e13c9d-f70b-439d-bfae-efa7ca65c07b"],

Cell["sun=Graphics[{PointSize[0.025],Point[{0,0}]}];", "Input",
 CellChangeTimes->{3.812188009931479*^9, 3.852188945393114*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"25ed41c2-df98-41e4-8ace-b58988592b4f"],

Cell[TextData[{
 "Define the value of the mass ratio, ",
 StyleBox["m2m1",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.8521179488724127`*^9, 3.852117988966939*^9}, {
   3.852192205494658*^9, 3.852192206493499*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"17c4fb23-07c4-4a1f-b239-9a70e3e05ba2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m2m1", "=", "0.2"}], ";"}]], "Input",
 CellChangeTimes->{{3.851757606778563*^9, 3.851757611696493*^9}, {
  3.851761249417083*^9, 3.8517612503290977`*^9}, {3.852117977402968*^9, 
  3.852117983281823*^9}, {3.852118358795034*^9, 3.852118368514513*^9}, {
  3.8521215483830967`*^9, 3.852121548893025*^9}, {3.852189529136189*^9, 
  3.8521895402051353`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"921bc2f3-947f-49de-ad90-fadf1c1b4231"],

Cell["\<\
Prepare the required ellipses.  Note that ell2 is the elliptical path taken \
by the orbiting mass with rewpect to the centre of mass.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.8521179488724127`*^9, 3.852117988966939*^9}, {
   3.852192205494658*^9, 3.852192206493499*^9}, {3.852197351187242*^9, 
   3.852197409016316*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cf9c9ae6-a21e-42f4-a9b4-60449524145a"],

Cell["ellcom1=ellipsecom1[m2m1/(1+m2m1),0.5];", "Input",
 CellChangeTimes->{
  3.812187616753561*^9, 3.85176071108153*^9, {3.852192144408927*^9, 
   3.8521921725512114`*^9}, {3.852192484956386*^9, 3.8521924859314623`*^9}, {
   3.8521925695577087`*^9, 3.852192576892569*^9}, {3.852193564980401*^9, 
   3.852193575301079*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"6c569547-aadc-428e-bdeb-d50d12cfd9b1"],

Cell["ellcom2=ellipsecom2[m2m1/(1+m2m1),0.5];", "Input",
 CellChangeTimes->{
  3.812187616753561*^9, 3.85176071108153*^9, {3.852192144408927*^9, 
   3.8521921725512114`*^9}, {3.852192484956386*^9, 3.8521924859314623`*^9}, {
   3.8521925695577087`*^9, 3.852192576892569*^9}, {3.852193564980401*^9, 
   3.8521935879530487`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"f9e35473-3695-4300-a082-610a2f24b370"],

Cell["ell2=ellipse[1-m2m1/(1+m2m1),0.5];", "Input",
 CellChangeTimes->{
  3.812187616753561*^9, 3.85176071108153*^9, {3.85219536296113*^9, 
   3.852195399539137*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"ceba9e33-0370-4480-9c48-437d46024358"],

Cell["\<\
Draw the 2D  position of the orbiting planet and its associated vectors for a \
specific value of the mean anomaly for the frame centred on the central mass \
(Sun).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.851858121478053*^9, 3.851858198847193*^9}, {
   3.852197421601698*^9, 3.8521974383087263`*^9}, {3.881476119329557*^9, 
   3.881476132521387*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"377e75f5-1ae8-46ab-ba50-f66e2c17a174"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"34", "*", 
    RowBox[{"Pi", "/", "50"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8814762715829897`*^9, 3.88147627317581*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"49226c1a-2284-45d0-b912-98ab7b9801f5"],

Cell["\<\
posv=position[m,1.0,0.5];
posvec=Take[posv,{1,2}];
rad=Last[posv];
com=(rad-rad/(1+m2m1))*posvec/Norm[posvec];
planline=Graphics[Line[{{0,0},posvec}]];
planet=Graphics[{PointSize[0.015],Point[posvec]}];
compt=Graphics[{EdgeForm[Black],White,Disk[com,0.025]}];
plot1=Show[ell,ellcom1,sun,planet,planline,compt,Axes->None,PlotRange->{{-2.2,\
1.2},{-1.2,1.2}}];\
\>", "Input",
 CellChangeTimes->{{3.81218776738144*^9, 3.812187806561784*^9}, {
   3.812187839457335*^9, 3.812187886015627*^9}, {3.85175337730943*^9, 
   3.851753381956236*^9}, {3.851756272938218*^9, 3.851756374502733*^9}, {
   3.851756738242207*^9, 3.851756826933384*^9}, {3.8517568647346773`*^9, 
   3.8517568654522943`*^9}, {3.851756973762414*^9, 3.851756998621937*^9}, {
   3.851757424108417*^9, 3.851757460662208*^9}, {3.8517575408532543`*^9, 
   3.85175754517625*^9}, {3.851757625602386*^9, 3.851757631897231*^9}, {
   3.851757750130831*^9, 3.851757751060164*^9}, {3.851757869480734*^9, 
   3.851757938973566*^9}, {3.851758022079694*^9, 3.851758036345688*^9}, {
   3.851758134286305*^9, 3.851758194022518*^9}, {3.851758412582055*^9, 
   3.8517584587720137`*^9}, {3.8517603710023527`*^9, 3.851760410976789*^9}, {
   3.851769275728834*^9, 3.851769325407998*^9}, {3.851769473360655*^9, 
   3.851769474148532*^9}, {3.8517695255689793`*^9, 3.8517695294677362`*^9}, {
   3.852117731539773*^9, 3.852117753360544*^9}, {3.852118426338582*^9, 
   3.852118440244215*^9}, {3.852121666707611*^9, 3.852121679000989*^9}, {
   3.852188964790765*^9, 3.852188991186961*^9}, {3.8521891026380043`*^9, 
   3.85218910893758*^9}, {3.852189516325194*^9, 3.8521895555196743`*^9}, {
   3.8521895916259823`*^9, 3.8521896864558163`*^9}, {3.852190552435647*^9, 
   3.852190558779806*^9}, {3.852190650266115*^9, 3.852190682740521*^9}, {
   3.852191382774794*^9, 3.85219138314088*^9}, {3.8521916720279827`*^9, 
   3.8521917858507757`*^9}, {3.852191986161977*^9, 3.8521920570190773`*^9}, {
   3.852192185675724*^9, 3.852192188898676*^9}, {3.852192273905651*^9, 
   3.852192278167666*^9}, 3.8521926636832733`*^9, {3.852193682326067*^9, 
   3.8521937107173023`*^9}, {3.8521937564898977`*^9, 
   3.8521937763442373`*^9}, {3.8521938772862797`*^9, 3.852193900088661*^9}, 
   3.852194264566958*^9, {3.852195407785874*^9, 3.8521954156230288`*^9}, {
   3.8814761398571177`*^9, 3.8814761901815767`*^9}, {3.8814762540364027`*^9, 
   3.8814762687276707`*^9}, {3.881476302982636*^9, 3.8814763168101463`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"5379821f-f57f-4040-ae58-e6e690f5d55c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Show", "[", "plot1", "]"}]}]], "Input",
 CellChangeTimes->{{3.8121878902475367`*^9, 3.812187944500083*^9}, {
   3.8521929112396507`*^9, 3.852192915895495*^9}, 3.852193779380034*^9, {
   3.8814758722503767`*^9, 3.881475873055388*^9}, {3.881476209052183*^9, 
   3.881476219621832*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"62895743-474f-408f-8c10-c0ea2cd2bfce"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUEifUKKQUVRKKe0upEiLaMhepZ2URJKMKJIt2ZK997zI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        "]]},
      Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001], Opacity[1.], 
       FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c8le/7APCSFBIVFSXZERWS0rgq0TIzIzSQZJZk770ysvfeHGfYXOcc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        "]]},
      Annotation[#, "Charting`Private`Tag$1959#1"]& ]}, {}}, 
   {PointSize[0.025], PointBox[{0, 0}]}, 
   {PointSize[0.015], PointBox[{-1.2726032228357411`, 0.5498301510901975}]}, 
   LineBox[{{0, 0}, {-1.2726032228357411`, 0.5498301510901975}}], 
   {GrayLevel[1], EdgeForm[GrayLevel[0]], 
    DiskBox[{-0.21210053713929006, 0.09163835851503285}, 0.025]}},
  Axes->None,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.8121878957474546`*^9, 3.8121879455719357`*^9}, 
   3.81218803698907*^9, {3.851753368679755*^9, 3.851753387309258*^9}, 
   3.851756392505612*^9, 3.851756943429625*^9, 3.851757003951313*^9, 
   3.851757435536717*^9, 3.851757473832941*^9, 3.851757562866273*^9, 
   3.851757639593557*^9, {3.8517577289734697`*^9, 3.851757755841049*^9}, {
   3.8517579033133574`*^9, 3.8517579426161613`*^9}, 3.851758041159957*^9, {
   3.8517581425478907`*^9, 3.85175819957152*^9}, 3.8517606346178503`*^9, 
   3.8517694782006197`*^9, 3.851769533744479*^9, 3.8517696979869967`*^9, 
   3.851769802668839*^9, 3.8518472412901773`*^9, 3.851849595963212*^9, 
   3.851850431745277*^9, 3.851858887881947*^9, 3.8519664203545628`*^9, {
   3.85196645585706*^9, 3.8519664716992273`*^9}, 3.8519665205990877`*^9, 
   3.852189714294421*^9, 3.852190564267267*^9, 3.852190698686198*^9, 
   3.8521913886117563`*^9, {3.852191731689749*^9, 3.852191790173222*^9}, 
   3.852192061658464*^9, 3.852192191731077*^9, {3.852192282450675*^9, 
   3.852192302720662*^9}, 3.852192493258628*^9, 3.8521925841654987`*^9, 
   3.852192669545429*^9, 3.8521928082348213`*^9, 3.852192856996648*^9, {
   3.852192917898354*^9, 3.8521929390312243`*^9}, {3.852193690343691*^9, 
   3.852193714994421*^9}, {3.852193762382668*^9, 3.852193784246551*^9}, 
   3.852195420862771*^9, 3.852197733617859*^9, 3.8521978650383453`*^9, 
   3.852198220940433*^9, 3.881475897311308*^9, 3.881476224746379*^9, 
   3.881476320565421*^9, 3.890898875842737*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"a0504048-67a8-42ae-88be-59b716aad087"]
}, Open  ]],

Cell["\<\
Now draw the 2D  position of the orbiting planet and its associated vectors \
for the same value of the mean anomaly for the frame centred on the centre of \
mass.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.851858121478053*^9, 3.851858198847193*^9}, {
   3.852197421601698*^9, 3.852197476725752*^9}, {3.881476338290254*^9, 
   3.881476388599187*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c29eb8c8-9051-49fd-b3cf-7d258507870f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"34", "*", 
    RowBox[{"Pi", "/", "50"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8814762715829897`*^9, 3.88147627317581*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"89404793-f8c7-498a-aa63-d353c373dad2"],

Cell["\<\
posv=position[m,1.0,0.5];
posvec=Take[posv,{1,2}];
rad=Last[posv];
com=(rad-rad/(1+m2m1))*posvec/Norm[posvec];
sun2=Graphics[{PointSize[0.025],Point[-com]}];
planline=Graphics[Line[{-com,posvec-com}]];
planet=Graphics[{PointSize[0.015],Point[posvec-com]}];
compt=Graphics[{EdgeForm[Black],White,Disk[{0,0},0.025]}];
plot2=Show[ell2,ellcom2,sun2,planet,planline,compt,Axes->None,PlotRange->{{-2.\
2,1.2},{-1.2,1.2}}];\
\>", "Input",
 CellChangeTimes->{{3.81218776738144*^9, 3.812187806561784*^9}, {
   3.812187839457335*^9, 3.812187886015627*^9}, {3.85175337730943*^9, 
   3.851753381956236*^9}, {3.851756272938218*^9, 3.851756374502733*^9}, {
   3.851756738242207*^9, 3.851756826933384*^9}, {3.8517568647346773`*^9, 
   3.8517568654522943`*^9}, {3.851756973762414*^9, 3.851756998621937*^9}, {
   3.851757424108417*^9, 3.851757460662208*^9}, {3.8517575408532543`*^9, 
   3.85175754517625*^9}, {3.851757625602386*^9, 3.851757631897231*^9}, {
   3.851757750130831*^9, 3.851757751060164*^9}, {3.851757869480734*^9, 
   3.851757938973566*^9}, {3.851758022079694*^9, 3.851758036345688*^9}, {
   3.851758134286305*^9, 3.851758194022518*^9}, {3.851758412582055*^9, 
   3.8517584587720137`*^9}, {3.8517603710023527`*^9, 3.851760410976789*^9}, {
   3.851769275728834*^9, 3.851769325407998*^9}, {3.851769473360655*^9, 
   3.851769474148532*^9}, {3.8517695255689793`*^9, 3.8517695294677362`*^9}, {
   3.852117731539773*^9, 3.852117753360544*^9}, {3.852118426338582*^9, 
   3.852118440244215*^9}, {3.852121666707611*^9, 3.852121679000989*^9}, {
   3.852188964790765*^9, 3.852188991186961*^9}, {3.8521891026380043`*^9, 
   3.85218910893758*^9}, {3.852189516325194*^9, 3.8521895555196743`*^9}, {
   3.8521895916259823`*^9, 3.8521896864558163`*^9}, {3.852190552435647*^9, 
   3.852190558779806*^9}, {3.852190650266115*^9, 3.852190682740521*^9}, {
   3.852191382774794*^9, 3.85219138314088*^9}, {3.8521916720279827`*^9, 
   3.8521917858507757`*^9}, {3.852191986161977*^9, 3.8521920570190773`*^9}, {
   3.852192185675724*^9, 3.852192188898676*^9}, {3.852192273905651*^9, 
   3.852192278167666*^9}, 3.8521926636832733`*^9, {3.852193682326067*^9, 
   3.8521937107173023`*^9}, {3.8521937564898977`*^9, 3.852193757026637*^9}, 
   3.852193787332144*^9, {3.852194271329784*^9, 3.852194274051474*^9}, {
   3.852194451933967*^9, 3.852194488716524*^9}, {3.8521945462154493`*^9, 
   3.852194548363082*^9}, {3.852194715735697*^9, 3.852194716949091*^9}, 
   3.852195425860371*^9, {3.852195980490164*^9, 3.8521959860900087`*^9}, {
   3.852196063919574*^9, 3.852196079222624*^9}, {3.8521962791328907`*^9, 
   3.8521963093060503`*^9}, {3.881476330145772*^9, 3.881476333579875*^9}, {
   3.881476378580459*^9, 3.881476404590888*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"07cff80a-df47-49a2-951a-4fd7d951b15c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"Show", "[", "plot2", "]"}]}]], "Input",
 CellChangeTimes->{{3.8521944929470587`*^9, 3.852194493300408*^9}, {
  3.8814758805819597`*^9, 3.8814758815552464`*^9}, {3.8814764094662447`*^9, 
  3.881476413619722*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"e9a5b3fb-6184-40e7-995c-9c43d06e7dee"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c41W/4B/AyKqHsUFRWSlIa2redBiUNaShK2TMqK4lSJDsrMiIrIyPS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        "]]},
      Annotation[#, "Charting`Private`Tag$2011#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c41e//OHD0LpXRLonMNJRZtp5GSqmMUJQyCknZRBGRrZAZ2dn7nGPz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        "]]},
      Annotation[#, "Charting`Private`Tag$1985#1"]& ]}, {}}, 
   {PointSize[0.025], PointBox[{0.21210053713929006`, -0.09163835851503285}]}, 
   {PointSize[0.015], PointBox[{-1.060502685696451, 0.4581917925751646}]}, 
   LineBox[{{0.21210053713929006`, -0.09163835851503285}, {-1.060502685696451,
     0.4581917925751646}}], 
   {GrayLevel[1], EdgeForm[GrayLevel[0]], DiskBox[{0, 0}, 0.025]}},
  Axes->None,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "ScalingFunctions" -> 
    None},
  PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.852194494701888*^9, 3.8521945545502043`*^9, 
  3.852194724409243*^9, 3.852195432131082*^9, 3.852195991434142*^9, 
  3.8521960836582212`*^9, 3.852196314691536*^9, 3.8521963786917057`*^9, 
  3.8521977347860937`*^9, 3.852197866449016*^9, 3.8521982223309107`*^9, 
  3.8814758986307573`*^9, 3.8814764202073402`*^9, 3.89089887853518*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"7c5aa29c-5b61-449f-8141-af6b47c47101"]
}, Open  ]],

Cell["\<\
Now display the two plots for the same value of the mean anomaly.  Note that \
the length of the line joining the central mass and the orbiting mass is the \
same in each case.  This is Fig.2.12.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.851858121478053*^9, 3.851858198847193*^9}, {
   3.852197421601698*^9, 3.852197476725752*^9}, {3.852197507288237*^9, 
   3.8521976438717422`*^9}, {3.8521976829263372`*^9, 3.85219768487731*^9}, {
   3.881475986858428*^9, 3.881475994882938*^9}, {3.881476437049301*^9, 
   3.881476452528969*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ed4d1a01-8690-4c82-abdf-28e854dc998f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{"{", 
   RowBox[{"p1", ",", "p2"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.8521959504958076`*^9, 3.852195951216456*^9}, {
  3.852196217263125*^9, 3.852196226530181*^9}, {3.852196523141815*^9, 
  3.852196526791142*^9}, {3.852196562339631*^9, 3.852196588049449*^9}, {
  3.852196721397249*^9, 3.852196820523336*^9}, {3.881475956409404*^9, 
  3.881475982614113*^9}, {3.88147646258088*^9, 3.8814764639145117`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"68d9ac9f-4163-440b-8714-8574dbaa2e04"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUEifUKKQUVRKKe0upEiLaMhepZ2URJKMKJIt2ZK997zI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            "]]},
          Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, {{{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001], Opacity[
           1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c8le/7APCSFBIVFSXZERWS0rgq0TIzIzSQZJZk770ysvfeHGfYXOcc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            "]]},
          Annotation[#, "Charting`Private`Tag$1959#1"]& ]}, {}}, 
       {PointSize[0.025], PointBox[{0, 0}]}, 
       {PointSize[0.015], 
        PointBox[{-1.2726032228357411`, 0.5498301510901975}]}, 
       LineBox[{{0, 0}, {-1.2726032228357411`, 0.5498301510901975}}], 
       {GrayLevel[1], EdgeForm[GrayLevel[0]], 
        DiskBox[{-0.21210053713929006, 0.09163835851503285}, 0.025]}},
      Axes->None,
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0., 0.}, {0., 0.}},
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "ScalingFunctions" -> None},
      PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {160., -111.17647058823529}, 
     ImageScaled[{0.5, 0.5}], {300., 211.76470588235293},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
    InsetBox[
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c41W/4B/AyKqHsUFRWSlIa2redBiUNaShK2TMqK4lSJDsrMiIrIyPS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            "]]},
          Annotation[#, "Charting`Private`Tag$2011#1"]& ]}, {}}, {{{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
           Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw123c41e//OHD0LpXRLonMNJRZtp5GSqmMUJQyCknZRBGRrZAZ2dn7nGPz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            "]]},
          Annotation[#, "Charting`Private`Tag$1985#1"]& ]}, {}}, 
       {PointSize[0.025], 
        PointBox[{0.21210053713929006`, -0.09163835851503285}]}, 
       {PointSize[0.015], PointBox[{-1.060502685696451, 0.4581917925751646}]},
        LineBox[{{
        0.21210053713929006`, -0.09163835851503285}, {-1.060502685696451, 
        0.4581917925751646}}], 
       {GrayLevel[1], EdgeForm[GrayLevel[0]], DiskBox[{0, 0}, 0.025]}},
      Axes->None,
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{0., 0.}, {0., 0.}},
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "ScalingFunctions" -> None},
      PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {480., -111.17647058823529}, 
     ImageScaled[{0.5, 0.5}], {300., 211.76470588235293},
     BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[255]},
  PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8521962277678947`*^9, 3.8521965892940493`*^9, {3.852196731747929*^9, 
   3.852196757725223*^9}, {3.852196791969554*^9, 3.852196821484713*^9}, 
   3.852197735097023*^9, 3.8521978667432613`*^9, 3.852198227314543*^9, 
   3.8814759040668488`*^9, {3.881475943348798*^9, 3.881475983693555*^9}, 
   3.8814764654526043`*^9, 3.89089887861465*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"a42196c6-2a22-4645-a4dc-d9e45e2cca5d"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{923, 636},
WindowMargins->{{534, Automatic}, {Automatic, 246}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"3bf083b2-9bb4-47fd-b5ac-79bdb0d463cc"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[531, 19, 387, 8, 53, "Text",ExpressionUUID->"e841da96-a3b1-47be-bdda-35da93d19369"],
Cell[921, 29, 234, 4, 67, "Section",ExpressionUUID->"e0c5f5c8-6081-4d1f-b6a3-e70fbf94be83"],
Cell[1158, 35, 509, 16, 72, "Text",ExpressionUUID->"037fe9f8-0973-4de7-8f87-9d81c9d6a588"],
Cell[1670, 53, 130, 1, 30, "Input",ExpressionUUID->"74d5f28f-491d-4df9-9a98-baf58f7ca2bb"],
Cell[1803, 56, 692, 18, 76, "Text",ExpressionUUID->"15a06966-ec76-434f-8cbd-b97cea0e1abb"],
Cell[2498, 76, 220, 5, 66, "Input",ExpressionUUID->"1a2b4798-3239-4416-8e3f-8237e4351cfd"],
Cell[2721, 83, 1098, 25, 122, "Text",ExpressionUUID->"1bc8946a-0165-4c8f-a798-407bae699c3c"],
Cell[3822, 110, 611, 11, 66, "Input",ExpressionUUID->"189049c2-9419-41be-929f-57b64959f251"],
Cell[4436, 123, 663, 11, 66, "Input",ExpressionUUID->"78be983d-800c-4e63-a839-32a0d43a5c31"],
Cell[5102, 136, 676, 16, 76, "Text",ExpressionUUID->"499ef0d3-896f-43ff-ad87-a50c6bd576da"],
Cell[5781, 154, 151, 1, 30, "Input",ExpressionUUID->"e98c7a92-aae2-4838-8992-553373aaa41c"],
Cell[5935, 157, 875, 21, 76, "Text",ExpressionUUID->"038f3591-2174-494e-ae16-414cdb11af73"],
Cell[6813, 180, 865, 19, 174, "Input",ExpressionUUID->"6dc29f0b-b5a3-4d3b-abbd-998f5350a3f8"],
Cell[7681, 201, 537, 9, 53, "Text",ExpressionUUID->"7c6a061f-df2a-45cd-b45d-24af7e38b1f7"],
Cell[8221, 212, 179, 2, 30, "Input",ExpressionUUID->"23829646-9796-4147-80ef-8e664b956745"],
Cell[8403, 216, 612, 9, 53, "Text",ExpressionUUID->"38e13c9d-f70b-439d-bfae-efa7ca65c07b"],
Cell[9018, 227, 205, 2, 30, "Input",ExpressionUUID->"25ed41c2-df98-41e4-8ace-b58988592b4f"],
Cell[9226, 231, 862, 17, 53, "Text",ExpressionUUID->"17c4fb23-07c4-4a1f-b239-9a70e3e05ba2"],
Cell[10091, 250, 464, 8, 30, "Input",ExpressionUUID->"921bc2f3-947f-49de-ad90-fadf1c1b4231"],
Cell[10558, 260, 956, 16, 53, "Text",ExpressionUUID->"cf9c9ae6-a21e-42f4-a9b4-60449524145a"],
Cell[11517, 278, 403, 6, 30, "Input",ExpressionUUID->"6c569547-aadc-428e-bdeb-d50d12cfd9b1"],
Cell[11923, 286, 405, 6, 30, "Input",ExpressionUUID->"f9e35473-3695-4300-a082-610a2f24b370"],
Cell[12331, 294, 245, 4, 30, "Input",ExpressionUUID->"ceba9e33-0370-4480-9c48-437d46024358"],
Cell[12579, 300, 987, 17, 76, "Text",ExpressionUUID->"377e75f5-1ae8-46ab-ba50-f66e2c17a174"],
Cell[13569, 319, 265, 6, 30, "Input",ExpressionUUID->"49226c1a-2284-45d0-b912-98ab7b9801f5"],
Cell[13837, 327, 2519, 39, 156, "Input",ExpressionUUID->"5379821f-f57f-4040-ae58-e6e690f5d55c"],
Cell[CellGroupData[{
Cell[16381, 370, 408, 7, 30, "Input",ExpressionUUID->"62895743-474f-408f-8c10-c0ea2cd2bfce"],
Cell[16792, 379, 36946, 618, 271, "Output",ExpressionUUID->"a0504048-67a8-42ae-88be-59b716aad087"]
}, Open  ]],
Cell[53753, 1000, 983, 17, 76, "Text",ExpressionUUID->"c29eb8c8-9051-49fd-b3cf-7d258507870f"],
Cell[54739, 1019, 265, 6, 30, "Input",ExpressionUUID->"89404793-f8c7-498a-aa63-d353c373dad2"],
Cell[55007, 1027, 2787, 43, 174, "Input",ExpressionUUID->"07cff80a-df47-49a2-951a-4fd7d951b15c"],
Cell[CellGroupData[{
Cell[57819, 1074, 336, 6, 30, "Input",ExpressionUUID->"e9a5b3fb-6184-40e7-995c-9c43d06e7dee"],
Cell[58158, 1082, 35704, 599, 271, "Output",ExpressionUUID->"7c5aa29c-5b61-449f-8141-af6b47c47101"]
}, Open  ]],
Cell[93877, 1684, 1164, 19, 76, "Text",ExpressionUUID->"ed4d1a01-8690-4c82-abdf-28e854dc998f"],
Cell[CellGroupData[{
Cell[95066, 1707, 549, 9, 30, "Input",ExpressionUUID->"68d9ac9f-4163-440b-8714-8574dbaa2e04"],
Cell[95618, 1718, 71953, 1210, 254, "Output",ExpressionUUID->"a42196c6-2a22-4645-a4dc-d9e45e2cca5d"]
}, Open  ]]
}
]
*)

